@@ -5,6 +5,14 @@ import (
 	_ "github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/protocol/trojanc"
 	_ "github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/protocol/vless"
 	_ "github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/protocol/vmess"
+
+	_ "github.com/mzz2017/gg/dialer/http"
+	_ "github.com/mzz2017/gg/dialer/shadowsocks"
+	_ "github.com/mzz2017/gg/dialer/shadowsocksr"
+	_ "github.com/mzz2017/gg/dialer/socks"
+	_ "github.com/mzz2017/gg/dialer/trojan"
+	_ "github.com/mzz2017/gg/dialer/v2ray"
+
 	"github.com/json-iterator/go/extra"
 	"github.com/mzz2017/gg/cmd"
 	"net/http"
