@@ -4,7 +4,6 @@ import (
 	"fmt"
 	"github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/pool"
 	"github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/protocol/shadowsocks"
-	"github.com/e14914c0-6759-480d-be89-66b7b7676451/BitterJohn/server"
 	"github.com/mzz2017/gg/infra/ip_mtu_trie"
 	"golang.org/x/net/dns/dnsmessage"
 	"inet.af/netaddr"
@@ -13,6 +12,11 @@ import (
 	"time"
 )
 
+const (
+	DefaultNatTimeout = 3 * time.Minute
+	DnsQueryTimeout   = 17 * time.Second // RFC 5452
+)
+
 type HijackResp struct {
 	Resp   []byte
 	Domain string
@@ -41,19 +45,27 @@ func (p *Proxy) handleUDP(lAddr net.Addr, data []byte) (err error) {
 				}
 				if len(respMsg.Answers) == 0 {
 					// no answer
+					p.log.Tracef("tgt dns response with no answer")
 					_, err = p.udpConn.WriteTo(respData, lAddr)
 					return err
 				}
-				// we only pick the first answer
-				realAnsA, okA := respMsg.Answers[0].Body.(*dnsmessage.AResource)
-				if !okA {
+				// we only pick the first A answer
+				var realAnsA *dnsmessage.AResource
+				for _, ans := range respMsg.Answers {
+					A, okA := ans.Body.(*dnsmessage.AResource)
+					if okA {
+						realAnsA = A
+						break
+					}
+				}
+				if realAnsA == nil {
 					// not a valid answer
-					_, err = p.udpConn.WriteTo(respData, lAddr)
-					return err
+					p.log.Tracef("tgt dns response is not valid: %v", respMsg.Answers)
+				} else {
+					ip := netaddr.IPFrom4(realAnsA.A)
+					p.realIPMapper.Set(hijackResp.AnsIP, ip)
+					p.log.Tracef("fakeIP:(%v) realIP:(%v)", hijackResp.AnsIP, ip)
 				}
-				ip := netaddr.IPFrom4(realAnsA.A)
-				p.realIPMapper.Set(hijackResp.AnsIP, ip)
-				p.log.Tracef("fakeIP:(%v) realIP:(%v)", hijackResp.AnsIP, ip)
 				_, err = p.udpConn.WriteTo(hijackResp.Resp, lAddr)
 				return err
 			}
@@ -126,15 +138,24 @@ func (p *Proxy) hijackDNS(data []byte) (resp *HijackResp, isDNSQuery bool) {
 	return nil, true
 }
 
+// SelectTimeout selects an appropriate timeout for UDP packet.
+func SelectTimeout(packet []byte) time.Duration {
+	var dMessage dnsmessage.Message
+	if err := dMessage.Unpack(packet); err != nil {
+		return DefaultNatTimeout
+	}
+	return DnsQueryTimeout
+}
+
 // select an appropriate timeout
 func selectTimeout(packet []byte) time.Duration {
 	al, _ := shadowsocks.BytesSizeForMetadata(packet)
 	if len(packet) < al {
 		// err: packet with inadequate length
-		return server.DefaultNatTimeout
+		return DefaultNatTimeout
 	}
 	packet = packet[al:]
-	return server.SelectTimeout(packet)
+	return SelectTimeout(packet)
 }
 
 // GetOrBuildUDPConn get a UDP conn from the mapping.
@@ -205,7 +226,7 @@ func (p *Proxy) relayUDP(laddr net.Addr, rConn net.PacketConn, timeout time.Dura
 		//if err := dmsg.Unpack(buf[:n]); err == nil {
 		//	p.log.Traceln(dmsg)
 		//}
-		_ = p.udpConn.SetWriteDeadline(time.Now().Add(server.DefaultNatTimeout)) // should keep consistent
+		_ = p.udpConn.SetWriteDeadline(time.Now().Add(DefaultNatTimeout)) // should keep consistent
 		_, err = p.udpConn.WriteTo(buf[:n], laddr)
 		if err != nil {
 			return
