@@ -4,7 +4,6 @@ import (
 	"encoding/binary"
 	"fmt"
 	"github.com/mzz2017/gg/proxy"
-	"github.com/sirupsen/logrus"
 	"inet.af/netaddr"
 	"net"
 	"reflect"
@@ -40,7 +39,7 @@ func (t *Tracer) exitHandler(pid int, regs *syscall.PtraceRegs) (err error) {
 		}
 		fd, errno := returnValueInt(regs)
 		if errno != 0 {
-			logrus.Infof("socket error: pid: %v, errno: %v", pid, errno)
+			t.log.Infof("socket error: pid: %v, errno: %v", pid, errno)
 			return nil
 		}
 		socketInfo := SocketMetadata{
@@ -68,12 +67,12 @@ func (t *Tracer) exitHandler(pid int, regs *syscall.PtraceRegs) (err error) {
 		fd := args[0]
 		socketInfo := t.getSocketInfo(pid, int(fd))
 		if socketInfo == nil {
-			logrus.Tracef("syscall.F_DUPFD: socketInfo cannot found: pid: %v, fd: %v", pid, fd)
+			t.log.Tracef("syscall.F_DUPFD: socketInfo cannot found: pid: %v, fd: %v", pid, fd)
 			return nil
 		}
 		newFD, errno := returnValueInt(regs)
 		if errno != 0 {
-			logrus.Tracef("socket error: pid: %v, errno: %v", pid, errno)
+			t.log.Tracef("socket error: pid: %v, errno: %v", pid, errno)
 			return nil
 		}
 		t.saveSocketInfo(pid, newFD, *socketInfo)
@@ -250,7 +249,7 @@ func pokeAddrToArgument(pid int, regs *syscall.PtraceRegs, bAddrToPoke []byte, p
 func (t *Tracer) checkSocket(pid int, fd uint64) (socketInfo *SocketMetadata, expected bool) {
 	socketInfo = t.getSocketInfo(pid, int(fd))
 	if socketInfo == nil {
-		logrus.Tracef("socketInfo of socket cannot found: pid: %v, fd: %v", pid, fd)
+		t.log.Tracef("socketInfo of socket cannot found: pid: %v, fd: %v", pid, fd)
 		return nil, false
 	}
 	switch socketInfo.Family {
@@ -282,6 +281,7 @@ func (t *Tracer) portHackTo(socketInfo *SocketMetadata) int {
 
 func (t *Tracer) network(socketInfo *SocketMetadata) string {
 	if socketInfo.Family != syscall.AF_INET && socketInfo.Family != syscall.AF_INET6 {
+		t.log.Tracef("network: unknown: family: %v, type: %v", socketInfo.Family, socketInfo.Type)
 		return ""
 	}
 	switch {
@@ -303,6 +303,7 @@ func (t *Tracer) network(socketInfo *SocketMetadata) string {
 			return "udp"
 		}
 	}
+	t.log.Tracef("network: unknown: family: %v, type: %v", socketInfo.Family, socketInfo.Type)
 	return ""
 }
 
@@ -311,9 +312,15 @@ func (t *Tracer) handleINet4(socketInfo *SocketMetadata, bSockAddr []byte) (sock
 	portHackTo := t.portHackTo(socketInfo)
 	addr := *(*RawSockaddrInet4)(unsafe.Pointer(&bSockAddr[0]))
 	targetPort := binary.BigEndian.Uint16(addr.Port[:])
+	if network == "udp" && targetPort == 0 {
+		// skip the usage with sin_port = 0
+		t.log.Tracef("handleINet4 (%v): skip sin_port=0", network)
+		return nil, nil
+	}
 	if network == "udp" && !t.supportUDP && targetPort != 53 {
 		// skip UDP traffic
 		// but only keep DNS packets sent to the port 53
+		t.log.Tracef("handleINet4 (%v): skip UDP", network)
 		return nil, nil
 	}
 	isDNS := network == "udp" && targetPort == 53
@@ -364,6 +371,11 @@ func (t *Tracer) handleINet6(socketInfo *SocketMetadata, bSockAddr []byte) (sock
 	addr := *(*RawSockaddrInet6)(unsafe.Pointer(&bSockAddr[0]))
 	targetPort := binary.BigEndian.Uint16(addr.Port[:])
 
+	if network == "udp" && targetPort == 0 {
+		// skip the usage with sin_port = 0
+		t.log.Tracef("handleINet6 (%v): skip sin_port=0", network)
+		return nil, nil
+	}
 	if network == "udp" && !t.supportUDP && targetPort != 53 {
 		// skip UDP traffic
 		// but only keep DNS packets sent to the port 53
